@@ -1,18 +1,15 @@
 import pythonbible as bible
 
 
-def test_format_scripture_references(normalized_references_complex):
+def test_format_scripture_references(
+    normalized_references_complex, formatted_reference
+):
     # Given a list of normalized references
     # When we format them into a reference string
-    formatted_reference = bible.format_scripture_references(
-        normalized_references_complex
-    )
+    reference = bible.format_scripture_references(normalized_references_complex)
 
     # Then the reference string is correctly formatted.
-    assert (
-        formatted_reference
-        == "Psalms 130:4,8;Jeremiah 29:32-30:10,31:12;Matthew 1:18-2:18;Luke 3:5-7"
-    )
+    assert reference == formatted_reference
 
 
 def test_format_scripture_references_null():
@@ -22,3 +19,16 @@ def test_format_scripture_references_null():
 
     # Then the result is null
     assert formatted_reference is None
+
+
+def test_format_scripture_references_sorting(
+    normalized_references_complex, formatted_reference
+):
+    # Given a list of normalized references that are not in proper order
+    normalized_references_complex.reverse()
+
+    # When we format them into a reference string
+    reference = bible.format_scripture_references(normalized_references_complex)
+
+    # Then the reference string is correctly formatted.
+    assert reference == formatted_reference
